* Multipliers. do

* Multipliers for government consumption vs. investment
* Valerie Ramey program for "The Macroeconomic Consequences of Infrastructure Investment"
* Nov. 10, 2020

* Requires: Simulation_irfs.xlsx, which contains simulation results from Dynare programs
clear all

capture log close

set more 1

set scheme s1color


scalar theta_gc = 0.05
scalar theta_gi_theta05 = 0.05
scalar theta_gi_theta10 = 0.1

scalar theta_gc = 0.05
scalar theta_gi_theta05 = 0.05
scalar theta_gi_theta10 = 0.1

foreach siml in neo_gc neo_gi_theta05 neo_gi_theta05_delays neo_gi_theta10 neo_gi_theta10_delays {

  clear
  
  import excel Simulation_irfs.xlsx, first sheet("`siml'")

  sort h
  
  scalar y_ss = y
  
  gen g = gc + gi
  scalar g_ss = g
  
  scalar apport_ss = apport
  
  * for multipliers
  
  gen ydiffss = y - y_ss
  gen gdiffss = g - g_ss
  gen apportdiffss = apport - apport_ss
  
 
  gen grossr = 1/0.99 if h==0
  replace grossr = (c[_n+1]/c)/0.99 if h>0
  
  gen grossrproduct = grossr if h==0
  
  gen r = 400*(grossr - 1)
  scalar r_ss = r
  
  gen r_`siml' = r - r_ss
  
  forvalues i = 1/1000 { 
    replace grossrproduct = grossr*grossrproduct[_n-1] if h==`i'	
  }
  
  gen ydiffss_pdv = ydiffss/grossrproduct
  gen gdiffss_pdv = gdiffss/grossrproduct
  gen apportdiffss_pdv = apportdiffss/grossrproduct
    
  gen mult_int_`siml' = sum(ydiffss)/sum(apportdiffss)
  gen mult_pdv_`siml' = sum(ydiffss_pdv)/sum(apportdiffss_pdv)
 
 tempfile z`siml'
  save `z`siml'' 
}
clear

use `zneo_gc'

merge 1:1 h using `zneo_gi_theta05', nogen
sort h
merge 1:1 h using `zneo_gi_theta10', nogen
sort h
merge 1:1 h using `zneo_gi_theta05_delays', nogen
sort h
merge 1:1 h using `zneo_gi_theta10_delays', nogen
sort h

keep h mult*

tempfile neo_multiplier
  save `neo_multiplier'

  clear

foreach siml in nk_gc nk_gi_theta05 nk_gi_theta05_delays nk_gi_theta10 nk_gi_theta10_delays {

  clear
  
  import excel Simulation_irfs.xlsx, first sheet("`siml'")

  sort h
  
  scalar y_ss = y
  
  gen g = gc + gi
  scalar g_ss = g
  
  scalar apport_ss = apport
  
  * for multipliers
  
  gen ydiffss = y - y_ss
  gen gdiffss = g - g_ss
  gen apportdiffss = apport - apport_ss
  
  gen gross_realr = 1/0.99 if h==0
  replace gross_realr = r/pi[_n+1] if h>0
  
  gen grossrproduct = gross_realr if h==0
  
  gen realr = 400*(gross_realr - 1)
  scalar realr_ss = realr
  
  gen realr_`siml' = realr - realr_ss
  
  forvalues i = 1/1000 { 
    replace grossrproduct = gross_realr*grossrproduct[_n-1] if h==`i'	
  }
  
  gen ydiffss_pdv = ydiffss/grossrproduct
  gen gdiffss_pdv = gdiffss/grossrproduct
  gen apportdiffss_pdv = apportdiffss/grossrproduct
    
  gen mult_int_`siml' = sum(ydiffss)/sum(apportdiffss)
  gen mult_pdv_`siml' = sum(ydiffss_pdv)/sum(apportdiffss_pdv)
 
 tempfile z`siml'
  save `z`siml''
  
}
clear

use `znk_gc'

merge 1:1 h using `znk_gi_theta05', nogen
sort h
merge 1:1 h using `znk_gi_theta10', nogen
sort h
merge 1:1 h using `znk_gi_theta05_delays', nogen
sort h
merge 1:1 h using `znk_gi_theta10_delays', nogen
sort h

tempfile nk_multiplier
  save `nk_multiplier'
  
  merge 1:1 h using `neo_multiplier'

keep h mult*


*** Figure 5 - Multipliers

 local var pdv  /* int pdv*/

 foreach model in neo {
   
 tw scatter mult_`var'_`model'_gc mult_`var'_`model'_gi_theta05 mult_`var'_`model'_gi_theta10 h if h<=20, c(l l l) clp(l - _) ms(i i i) ///
       clc(black blue orange) mc(black blue orange) title("No Delays", size(medsmall)) ///
	   ylabel(0.2 0.4 0.6) ///
       legend(off) xtitle("quarter") name(m`model'`var'graph) 
   
 tw scatter mult_`var'_`model'_gc mult_`var'_`model'_gi_theta05_delays mult_`var'_`model'_gi_theta10_delays h if h<=20, c(l l l) clp(l - _) ms(i i i) ///
        clc(black blue orange) mc(black blue orange) title("Time to Spend and Build", size(medsmall)) ///
		ylabel(.2 .3 .4 .5) ///
         legend(off) xtitle("quarter") name(m`model'`var'delaygraph) 

}

foreach model in nk {
   
 tw scatter mult_`var'_`model'_gc mult_`var'_`model'_gi_theta05 mult_`var'_`model'_gi_theta10 h if h<=20, c(l l l) clp(l - _) ms(i i i) ///
       clc(black blue orange) mc(black blue orange) title("No Delays", size(medsmall)) ///
	   ylabel(.8 1 1.2 1.4) ///
       legend(off) xtitle("quarter") name(m`model'`var'graph) 
   
 tw scatter mult_`var'_`model'_gc mult_`var'_`model'_gi_theta05_delays mult_`var'_`model'_gi_theta10_delays h if h<=20, c(l l l) clp(l - _) ms(i i i) ///
        clc(black blue orange) mc(black blue orange) title("Time to Spend and Build", size(medsmall)) ///
        ylabel(0 .5 1 1.5) ///
		legend(off) xtitle("quarter") name(m`model'`var'delaygraph) 

}

*graph combine mneo`var'graph mneo`var'delaygraph, title("Neoclassical Model") iscale(1.8) col(2) name(neo_m`var'graph) ysize(3) xsize(8)
*graph combine mnk`var'graph mnk`var'delaygraph, title("New Keynesian Model") iscale(1.8) col(2) name(nk_m`var'graph) ysize(3) xsize(8) 

graph combine mneo`var'graph mneo`var'delaygraph, title("Neoclassical Model") col(2) name(neo_m`var'graph) iscale(1.3)
graph combine mnk`var'graph mnk`var'delaygraph, title("New Keynesian Model") col(2) name(nk_m`var'graph) iscale(1.3)

graph combine neo_m`var'graph nk_m`var'graph, col(1) ysize(6) xsize(5)

**** Table 2 - Short-run Multipliers

list h mult_int_neo_gc mult_int_neo_gi_theta05 mult_int_neo_gi_theta05_delays if h==4, abbrev(25)
list h mult_int_nk_gc mult_int_nk_gi_theta05 mult_int_nk_gi_theta05_delays if h==4, abbrev(25)

**** Table 3 - Long-run Multipliers

list h mult_pdv_neo* if h==1000, abbrev(25)
list h mult_int_neo* if h==1000, abbrev(25)

list h mult_pdv_nk* if h==1000, abbrev(25)
list h mult_int_nk* if h==1000, abbrev(25)
  

